Crate serde_dhall_typegen

Crate serde_dhall_typegen 

Attribute Macros

dhall_types
Create serialization-compatible Rust types in the following mod for the Dhall types contained in a given folder. Hand-written impls can be included in the mod block. By default, the generated types are named as the Pascal case of the Dhall file they are defined in (e.g. my_type.dhall -> MyType), but this can be overwritten (see Dhall metadata). Any sub-unions or records contained within these files will be assigned an arbitrary name by default (which may change between compiles).